[![Build Status](https://travis-ci.org/victor-valencia/bootstrap-iconpicker.svg?branch=master)](https://travis-ci.org/victor-valencia/bootstrap-iconpicker)
[![Code Climate](https://codeclimate.com/github/victor-valencia/bootstrap-iconpicker/badges/gpa.svg)](https://codeclimate.com/github/victor-valencia/bootstrap-iconpicker)
[![npm](http://img.shields.io/npm/v/bootstrap-iconpicker.svg)](https://npmjs.org/package/bootstrap-iconpicker)
[![Bower](http://img.shields.io/bower/v/bootstrap-iconpicker.svg)](http://bower.io/search/?q=bootstrap-iconpicker)
[![Release](http://img.shields.io/github/release/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/releases)
[![Tag](http://img.shields.io/github/tag/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/tags)
[![Issues](http://img.shields.io/github/issues/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/issues?q=is%3Aopen)
[![Issues](http://img.shields.io/badge/license-MIT-red.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/blob/master/LICENSE)

# [Bootstrap-Iconpicker v1.10.0](http://victor-valencia.github.io/bootstrap-iconpicker)
![Iconpicker](../bootstrap-iconpicker_4x.png)

A simple iconpicker for Bootstrap 3.x and 4.x.

## Table of contents
- [Supported iconset](#supported-iconset)

## Supported Iconset
| Iconset | Versions |
| --- | --- |
| [Elusive Icons](http://press.codes/downloads/elusive-icons-webfont/) | v2.0.0 (lastest) |
| [Flag Icons](http://flag-icon-css.lip.is/) | v2.8.0 (lastest) |
| [Font Awesome Icons](http://fontawesome.io/) | v5.3.1 (lastest), v4.7.0, v4.6.0, v4.5.0, v4.4.0, v4.3.0, v4.2.0, v4.1.0, v4.0.0 |
| Glyphicons | v3.3.7 (lastest) |
| [Ionicons](http://ionicons.com/) | v2.0.1 (lastest), v1.5.2 |
| [Map Icons](http://map-icons.com/) | v2.1.0 (lastest) |
| [Material Design Icons](http://zavoloklom.github.io/material-design-iconic-font/) | v2.2.0 (lastest), v2.1.2, v2.1.1, v2.1.0, v2.0.2, v2.0.1, v2.0.0 |
| [Octicons](https://octicons.github.com/) | v4.4.0 (lastest), v4.3.0, v4.2.1, v4.2.0, v4.1.1, v4.1.0, v4.0.0, v3.5.0, v3.4.1, v3.4.0, v3.3.0, v3.2.0, v3.1.0, v3.0.0, v2.4.1, v2.4.0, v2.3.0, v2.2.2, v2.2.1, v2.2.0, v2.1.2, v2.1.1, v2.1.0, v2.0.2, v2.0.1, v2.0.0 |
| [Typicons](http://typicons.com) | v2.0.9 (lastest), v2.0.8, v2.0.7, v2.0.6, v2.0.5, v2.0.4, v2.0.3, v2.0.2, v2.0.1 |
| [Weather Icons](http://erikflowers.github.io/weather-icons/) | v2.0.10 (lastest), v1.2.0 |
